==> 0.6.2.tar.gz: lib/src/authorizer/authorizer.dart <==
library jaguar_auth.authoriser;

import 'dart:async';
import 'package:jaguar/jaguar.dart';
import 'package:jaguar_auth/src/entity/entity.dart';
import 'package:jaguar_session/jaguar_session.dart';

/// Authorizes the request
///
/// Arguments:
/// It uses [sessionManager] is used to parse and fetch session information from
/// the request
///
/// It uses [modelManager] to fetch user model of the logged-in user
///
/// Outputs ans Variables:
/// The authorised user model is injected into the context as input
///
/// [sessionManager] is added to context variable for usage in route handler or
class Authorizer extends Interceptor {
  /// Session manager to parse and fetch session information from the request
  final SessionManager sessionManager;

  /// Model manager used to fetch user model of the logged-in user
  final AuthModelManager modelManager;

  /// The key by which authorizationId is stored in session data
  final String authorizationIdKey;

  Authorizer(this.modelManager,
      {this.authorizationIdKey: 'id', SessionManager sessionManager})
      : sessionManager = sessionManager != null
            ? sessionManager
            : new CookieSessionManager();

  Future<AuthorizationUser> pre(Context ctx) async {
    await sessionManager.parseRequest(ctx.req);
    await sessionManager.validate();

    String id = sessionManager.getInValue(authorizationIdKey);
    if (id is! String || id.isEmpty) {
      throw new UnAuthorizedError();
    }

    AuthorizationUser subject =
        await modelManager.fetchModelByAuthorizationId(id);

    if (subject == null) {
      throw new UnAuthorizedError();
    }

    ctx.addVariable(SessionManager);

    return subject;
  }

  Future<Response> post(Context ctx, Response resp) async {
    return await sessionManager.updateResponse(ctx.req, resp);
  }
}

==> 0.9.1.tar.gz: lib/src/authorizer/authorizer.dart <==
library jaguar_auth.authoriser;

import 'dart:async';
import 'package:jaguar/jaguar.dart';
import 'package:jaguar_auth/src/entity/entity.dart';
import 'package:jaguar_session/jaguar_session.dart';

/// Authorizes the request
///
/// Arguments:
/// It uses [sessionManager] is used to parse and fetch session information from
/// the request
///
/// It uses [modelManager] to fetch user model of the logged-in user
///
/// Outputs ans Variables:
/// The authorised user model is injected into the context as input
///
/// [sessionManager] is added to context variable for usage in route handler or
class Authorizer extends Interceptor {
  /// Session manager to parse and fetch session information from the request
  final SessionManager sessionManager;

  /// Model manager used to fetch user model of the logged-in user
  final AuthModelManager modelManager;

  /// The key by which authorizationId is stored in session data
  final String authorizationIdKey;

  Authorizer(this.modelManager,
      {this.authorizationIdKey: 'id', SessionManager sessionManager})
      : sessionManager = sessionManager != null
            ? sessionManager
            : new CookieSession();

  Future<AuthorizationUser> pre(Context ctx) async {
    await sessionManager.parseRequest(ctx.req);
    await sessionManager.validate();

    String id = sessionManager.getInValue(authorizationIdKey);
    if (id is! String || id.isEmpty) {
      throw new UnAuthorizedError();
    }

    AuthorizationUser subject =
        await modelManager.fetchModelByAuthorizationId(ctx, id);

    if (subject == null) {
      throw new UnAuthorizedError();
    }

    ctx.addVariable(SessionManager);

    return subject;
  }

  Future<Response> post(Context ctx, Response resp) async {
    return await sessionManager.writeResponse(ctx.req, resp);
  }
}
